@@ -53,7 +53,6 @@ static GdkPixbuf *screenshot = NULL;
 static char *last_save_dir = NULL;
 static char *window_title = NULL;
 static char *temporary_file = NULL;
-static gboolean drop_shadow = TRUE;
 static gboolean save_immediately = FALSE;
 
 /* Options */
@@ -100,7 +99,6 @@ static char *
 generate_filename_for_uri (const char *uri)
 {
   char *retval;
-  char *tmp;
   char *file_name;
   int i = 1;
 
@@ -117,10 +115,8 @@ generate_filename_for_uri (const char *uri)
       file_name = g_strdup (_("Screenshot.png"));
     }
 
-  tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, NULL);
-  retval = g_build_filename (uri, tmp, NULL);
+  retval = g_build_filename (uri, file_name, NULL);
   g_free (file_name);
-  g_free (tmp);
 
   do
     {
@@ -163,10 +159,8 @@ generate_filename_for_uri (const char *uri)
 	  file_name = g_strdup_printf (_("Screenshot-%d.png"), i);
 	}
 
-      tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, NULL);
-      retval = g_build_filename (uri, tmp, NULL);
+      retval = g_build_filename (uri, file_name, NULL);
       g_free (file_name);
-      g_free (tmp);
 
       i++;
     }
@@ -318,13 +312,17 @@ prepare_screenshot (void)
 
   screenshot = screenshot_get_pixbuf (win);
 
-  if (take_window_shot && drop_shadow)
-    {
-      GdkPixbuf *old = screenshot;
-
-      screenshot = screenshot_add_shadow (screenshot);
-      g_object_unref (old);
-    }
+  if (take_window_shot) {
+    if (g_str_equal (border_effect, "shadow"))
+      {
+        screenshot_add_shadow (&screenshot);
+      }
+    else 
+      if (g_str_equal (border_effect, "border"))
+        {
+          screenshot_add_border (&screenshot);
+        }
+  }
 
   screenshot_release_lock ();
 
@@ -392,6 +390,7 @@ load_options (void)
 
   include_border = gconf_client_get_bool (gconf_client, "/apps/gnome-screenshot/include_border", NULL);
   border_effect = gconf_client_get_string (gconf_client, "/apps/gnome-screenshot/border_effect", NULL);
+  g_print ("border_effect: %s\n", border_effect);
 
   g_object_unref (gconf_client);
 }
