@@ -107,9 +107,12 @@ struct _GSearchWindow {
 	GtkCellRenderer       * search_results_name_cell_renderer;
 	GtkTreeSelection      * search_results_selection;
 	GtkTreeIter             search_results_iter;
+	GtkTreePath           * search_results_hover_path;
 	GHashTable            * search_results_filename_hash_table;
 	GHashTable            * search_results_pixbuf_hash_table;
 	gchar                 * search_results_date_format_string;
+	gint		        show_thumbnails_file_size_limit;
+	gboolean		show_thumbnails;
 	gboolean                is_search_results_single_click_to_activate;
 	gboolean		is_locate_database_available;
 
