@@ -1,4 +1,3 @@
-
 /*  ----------------------------------------------------------------------
 
     Copyright (C) 1998  Cesar Miquel  (miquel@df.uba.ar)
@@ -19,35 +18,18 @@
 
     ---------------------------------------------------------------------- */
 
-
-#include <sys/stat.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <malloc.h>
-#include <string.h>
-#include "logview.h"
-
 #ifndef __LOGRTNS_H__
 #define __LOGRTNS_H__
 
-#ifdef FIXME
-int ReadNPagesUp (Log * lg, Page * pg, int n);
-int ReadNPagesDown (Log * lg, Page * pg, int n);
-int ReadPageUp (Log * lg, Page * pg);
-#endif
+#include "logview.h"
 
-int isLogFile (char *filename);
-int isSameDay (time_t day1, time_t day2);
+int isLogFile (char *filename, gboolean show_error);
 int WasModified (Log *log);
-void reverse (char *line);
-void ParseLine (char *buff, LogLine * line);
-void MoveToMark ();
-void ReadLogStats (Log * log);
-void UpdateLogStats( Log *log );
+void ParseLine (char *buff, LogLine * line, gboolean has_date);
 void CloseLog (Log * log);
 time_t GetDate (char *line);
-Log * OpenLogFile (char *filename);
-int ReadPageDown (Log *log, LogLine ***inp_mon_lines, gboolean exec_actions);
+Log * OpenLogFile (char *filename, gboolean show_error);
+gchar **ReadLastPage (Log *log);
+gchar **ReadNewLines (Log *log);
 
 #endif /* __LOGRTNS_H__ */
